;; Generated package description from pyim.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "pyim" "5.3.6.0.20251230.80953" "A Chinese input method support quanpin, shuangpin, wubi, cangjie and rime." '((emacs "27.1") (async "1.6") (xr "1.13")) :commit "a56c8d992c872addcfc295c409a7bae70d00af87" :authors '(("Ye Wenbin" . "wenbinye@163.com") ("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("convenience" "chinese" "pinyin" "input-method") :url "https://github.com/tumashu/pyim")
